"""
Script for NodeBaseComboBox
"""

from NodeUtil.NodeObjectUtil import NodeObjectUtil
from NodeUtil import NodeParameterTest

from InputControls.NodeBaseControl import NodeBaseControl

class NodeBaseComboBox(NodeBaseControl):
    """
    Definition of class NodeBaseComboBox
    """

    def __init__(self, init_data, value_name, value_list_name, allow_empty_list):
        """ Initialize """

        super().__init__(init_data, value_name)

        self.value_ctrl       = self.get_control_property(value_name)
        self.value_list       = self.value_ctrl.value_list
        self.value_list_name  = value_list_name
        self.allow_empty_list = allow_empty_list

        build_ele = self.build_ele

        self.value_prop      = build_ele.get_property(value_name)
        self.value_list_prop = build_ele.get_property(value_list_name)

        if self.value_prop.value_type == "dynamicstringcombobox":
            self.update_dynamic_combobox(self.value_ctrl, self.value_list )


    def _create_output(self):
        """ Execute the node """

        build_ele = self.build_ele

        values = NodeObjectUtil.create_objects_list(self.value_list_prop.value)

        if self.allow_empty_list and not values:
            return

        if NodeParameterTest.test_empty_parameter(self, build_ele, self.value_list_name):
            return

        value_list = "|".join(map(str, values))

        if value_list == self.value_list:
            return

        self.value_list            = value_list
        self.value_ctrl.value_list = value_list

        if not self.value_prop.value in values:
            self.value_prop.value = values[0]

        if self.value_prop.value_type == "dynamicstringcombobox":
            self.update_dynamic_combobox(self.value_ctrl, value_list)

        self.enable_need_update()
