"""
Script for NodeTableRowSelection
"""

import NemAll_Python_Utility as AllplanUtil

from Utils.TabularDataUtil import read_csv

from NodeUtil import NodeBase, NodeFileUtil

NodeBase.trace_node_name('NodeTableRowSelection')

def create_node(init_data):
    """
    Create the NodeTableRowSelection

    Args:
        init_data:  data for the node initialization
    """

    return NodeTableRowSelection(init_data)


class NodeTableRowSelection(NodeBase):
    """
    Definition of class NodeTableRowSelection
    """

    def __init__(self, init_data):
        """
        Initialization of class NodeDoubleTeeBeamSizing

        Args:
            init_data:  data for the node initialization
        """

        super().__init__(init_data)

        info_picture = self.get_control_property("InfoPicture")
        sel_entry    = self.get_control_property("SelectedEntry")

        info_picture.row_name = sel_entry.text
        sel_entry.row_name    = sel_entry.text


    def _create_output(self):
        """
        Create the palette data
        """

        build_ele = self.build_ele

        if build_ele.FileName.value:
            self.read_entries()
        else:
            self.create_value_list([], "")


    def read_entries(self):
        """ read the entries """

        build_ele  = self.build_ele


        #----------------- read the entries

        file_name = NodeFileUtil.extend_file_path(build_ele.FileName.value)

        try:
            entries = read_csv(file_name)

        except:
            entries = []

            self.create_value_list([], "")

            AllplanUtil.ShowMessageBox("File \n\n" + file_name + "\n\n doesn't exist!",
                                       AllplanUtil.MB_OK)
            return

        if not entries:
            AllplanUtil.ShowMessageBox("File \n\n" + file_name + "\n\n is empty!",
                                       AllplanUtil.MB_OK)

            self.create_value_list([], "")

            return

        self.create_value_list(entries, file_name)


    def create_value_list(self, entries, file_name):
        """ create the value list with all entries """

        build_ele  = self.build_ele
        value_list = ""

        entry_names = [entry[0] for entry in entries]

        if build_ele.AdditionalEntry.value:
            entry_names.append(build_ele.AdditionalEntry.value)

        value_list = "|".join(entry_names)

        self.get_control_property("SelectedEntry").value_list = value_list

        if build_ele.SelectedEntry.value in entry_names:
            return

        if build_ele.SelectedEntry.value == "":
            build_ele.SelectedEntry.value = entry_names[0] if entry_names else build_ele.AdditionalEntry.value
            return

        AllplanUtil.ShowMessageBox("Entry " + build_ele.SelectedEntry.value + " not found in " + \
                                    file_name, AllplanUtil.MB_OK)

        if build_ele.AdditionalEntry.value:
            build_ele.SelectedEntry.value = build_ele.AdditionalEntry.value
        elif entry_names:
            build_ele.SelectedEntry.value = entry_names[0]
